%
% file:      	surf2solid_ex.m, (c) Matthew Roughan, Wed Mar  9 2011
% directory:   /home/mroughan/src/matlab/STL/
% created: 	Wed Mar  9 2011 
% author:  	Matthew Roughan 
% email:   	matthew.roughan@adelaide.edu.au
% 
% Examples of converting a surface to a solid for printing
%


% do the "peaks" function from Matlab
[X,Y] = meshgrid(-3:.125:3);
Z = peaks(X,Y) / 3;

% convert to a solid
[X_out, Y_out, Z_out] = surf2solid(X, Y, Z, 40, 1);
print('-dpng', 'Plots/surf2solid_ex.png');

% output a STL version of the solid
filename = 'STL/surf2solid_ex.stl';
mode = 'binary';
surf2stl(filename,X_out,Y_out,Z_out,mode);


% do Gary's surface
clear;
d = 0.05;
x = -1:d:1;
y = -1:d:1;
[X,Y] = meshgrid(x, y);

theta = atan2(Y, X);
r = sqrt( X.^2 + Y.^2 );

Z = r .* sin( 3*theta ) / 3;

% create a surface from the function
[X_out, Y_out, Z_out] = surf2solid(X, Y, Z);
print('-dpng', 'Plots/garys_surface.png');

% now output the surface
filename = 'STL/garys_surface.stl';
mode = 'binary';
surf2stl(filename,X_out,Y_out,Z_out,mode)

